@@ -37,6 +37,7 @@ class TornadoHTTPClient(CurlAsyncHTTPClient):
         self._cookie = {}
         self._proxy = {}
         self._user_agent = None
+        self.keep_alive = True
         self.use_cookie = True
         self.debug = False
         self.verify_ssl = False
@@ -102,6 +103,10 @@ class TornadoHTTPClient(CurlAsyncHTTPClient):
         if callable(callback):
             callback = self.wrap_callback(callback, args, kw)
 
+
+        headers = kwargs.pop("headers", {})
+        self.keep_alive and headers.update(Connection = "keep-alive")
+
         super(TornadoHTTPClient, self).fetch(request, callback, **kwargs)
 
 
